@@ -2,12 +2,12 @@
  *                 Mathematical Object Library                 *
  *        Combinatorial Analysis Library - Include File        *
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 0.2.0                   *
+ *	             GNU/linux version 0.2.2                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2004,2005,2006 COLLARD Christophe
- * copyright  2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2004,2005,2006,2007 COLLARD Christophe
+ * copyright  2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*! \class combinatorial_analysis
@@ -36,11 +36,11 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006 Christophe COLLARD \n
-	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.2.0
-    \date 2004-2006
+    \author copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007 Christophe COLLARD \n
+	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
+	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+    \version 0.2.2
+    \date 2004-2007
     \bug none
     \warning none
 */
@@ -82,9 +82,9 @@ template <class T> class combinatorial_analysis
 {
   private :
     void combinations (int, const vector<T>&, vector<T>&, matrix<T>&, int&,  int=1);
-    //    combinatorial_analysis() {}
+
   public :
-    friend int Cnp (int, int);
+    friend unsigned long int Cnp (int, int);
     template <class M> friend matrix<M> combinations (int, const vector<M>&);
 };
 
@@ -114,9 +114,9 @@ template <class T> void combinatorial_analysis<T>::combinations
   \return q : number of arrangements of two groups of p and n-p indistinguishable objects
 */
 
-//--------------------
-int Cnp (int n, int p)
-//--------------------
+//----------------------------------
+unsigned long int Cnp (int n, int p)
+//----------------------------------
 {
   assert (p>=0 && n>=p);
 
@@ -128,7 +128,8 @@ int Cnp (int n, int p)
   for (int i=2; i<=(n-p); i++)
     q /= i;
 
-  assert (q == int(q));
+  q = round(q);
+  assert (q == (unsigned long int) q);
 
   return q;
 }
