@@ -1,12 +1,12 @@
 /***************************************************************
  *                 Mathematical Object Library                 *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.3.2                   *
+ *                   GNU/linux version 0.3.6                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2002,2005,2006 COLLARD Christophe
- * copyright  2002,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2002,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2002,2005,2006,2007,2008 COLLARD Christophe
+ * copyright  2002,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2002,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*!
@@ -35,11 +35,11 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2005, 2006 Christophe COLLARD \n
-	    copyright \htmlonly &#169; \endhtmlonly 2002, 2005, 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	    copyright \htmlonly &#169; \endhtmlonly 2002, 2005, 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.3.2
-    \date 2002-2006
+    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2005, 2006, 2007, 2008 Christophe COLLARD \n
+	    copyright \htmlonly &#169; \endhtmlonly 2002, 2005, 2006, 2007, 2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
+	    copyright \htmlonly &#169; \endhtmlonly 2002, 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+    \version 0.3.6
+    \date 2002-2008
     \bug none
     \warning none
 */
@@ -96,6 +96,22 @@ template <class T> int sgn (T x)
 }
 
 
+//---------------------------------
+template <class T> T sup (T a, T b)
+//---------------------------------
+{
+  return (a>b) ? a : b;
+}
+
+
+//---------------------------------
+template <class T> T inf (T a, T b)
+//---------------------------------
+{
+  return (a<b) ? a : b;
+}
+
+
 //---------------
 long double pi ()
 //---------------
@@ -127,4 +143,17 @@ template <class T> int inv_factorial (T number)
 }
 
 
+//-----------------------------------------------------------------------------
+template <typename T> bool relative_error (T a, T b, long double eps = epsilon)
+//-----------------------------------------------------------------------------
+{
+  bool test;
+
+  if (!a) test = abs (a - b) < eps;
+  else    test = abs ((a-b)/a) < eps;
+
+  return test;
+}
+
+
 #endif
