@@ -2,14 +2,14 @@
  *                 Mathematical Object Library                 *
  *	      class matrix:  declarations for matrix	       *
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 1.9.30                  *
+ *	             GNU/linux version 1.9.34                  *
  *            software under General Public License            *
  ***************************************************************
- * copyright  1995,1996,1999,2000,2001,2002,2003,2004,2005,2006 COLLARD Christophe
+ * copyright  1995,1996,1999,2000,2001,2002,2003,2004,2005,2006,2007 COLLARD Christophe
  * copyright  2002,2003,2004 CREUSE Emmanuel
  * copyright  2003,2004 MERCIER Denis
- * copyright  2002,2003,2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2002,2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*! \class matrix
@@ -38,13 +38,13 @@
     </FONT>
     \endhtmlonly
 
-    \authors copyright \htmlonly &#169; \endhtmlonly 1995, 1996, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Christophe COLLARD \n
+    \authors copyright \htmlonly &#169; \endhtmlonly 1995, 1996, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Christophe COLLARD \n
              copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004 Emmanuel CREUSE \n
 	     copyright \htmlonly &#169; \endhtmlonly 2003, 2004 Denis MERCIER \n
-	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 1.9.30
-    \date 1995-2006
+	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
+	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+    \version 1.9.34
+    \date 1995-2007
     \bug none
     \warning none
 */
@@ -111,7 +111,6 @@ template <class T> class matrix
     virtual int Columns () const {return nbColumns;}     // returns the # of columns
     virtual void create (int,int);  // partial memory allocation (don't use this function except if you know what you're doing !!)
     virtual void assign (int,int);  // allocates memory without initilizing the matrix components to zero (so use it with great care)
-    operator int () const {return nbRows;}  // cast operator : matrix -> int
     friend bool operator ! (const matrix<T>& a) {return !a.nbRows;}
 
     virtual T&   operator () (int,int) const;
@@ -149,8 +148,11 @@ template <class T> class matrix
     template <class Tf> friend matrix<Tf> gauss (matrix<Tf>);     // computes matrix inversion with gauss algorithm
     template <class Tf> friend bool inv (matrix<Tf>&);            // same function as gauss but returns the inversion result 0/1
     //    friend matrix<T> gauss_pt <T> (matrix<T>);              // computes matrix inversion with gauss algorithm
-    virtual void save (const char*);  // writes to disk
-    virtual void read (const char*);  // reads from disk
+// i/o disk
+    virtual void save (const char*);
+    virtual void save (const string&);
+    virtual void read (const char*);
+    virtual void read (const string&);
     template <class Tf> friend matrix<Tf> kronecker (int); // return the identity matrix (ie. i==j -> 1 and i!=j -> 0)
     matrix<T>& approximation ();
     virtual void permute_rows (int,int);     // permutes matrix rows
@@ -892,6 +894,13 @@ template <class T> matrix<T> gauss_pt (matrix<T> mat)
 }
 */
 
+
+/*!
+  \brief Writes matrix to hard disk.
+
+  \param path path and filename
+*/
+
 //--------------------------------------------------------
 template <class T> void matrix<T>::save (const char* path)
 //--------------------------------------------------------
@@ -903,6 +912,27 @@ template <class T> void matrix<T>::save (const char* path)
 }
 
 
+/*!
+  \brief Writes matrix to hard disk.
+
+  \param filename path and filename
+*/
+
+//--------------------------------------------------------------
+template <class T> void matrix<T>::save (const string& filename)
+//--------------------------------------------------------------
+{
+  const char *path = filename.c_str();
+  save (path);
+}
+
+
+/*!
+  \brief Reads matrix from hard disk.
+
+  \param path path and filename
+*/
+
 //--------------------------------------------------------
 template <class T> void matrix<T>::read (const char* path)
 //--------------------------------------------------------
@@ -914,6 +944,21 @@ template <class T> void matrix<T>::read (const char* path)
 }
 
 
+/*!
+  \brief Reads matrix from hard disk.
+
+  \param filename path and filename
+*/
+
+//--------------------------------------------------------------
+template <class T> void matrix<T>::read (const string& filename)
+//--------------------------------------------------------------
+{
+  const char *path = filename.c_str();
+  read (path);
+}
+
+
 //-------------------------------------------------------
 template <class T> matrix<T>& matrix<T>::approximation ()
 //-------------------------------------------------------
