@@ -2,13 +2,13 @@
  *                 Mathematical Object Library                 *
  *     class symmatrix:  declarations for symmetric matrix     *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 1.4.6                   *
+ *                   GNU/linux version 1.4.8                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2002,2003,2004,2005,2006 COLLARD Christophe
+ * copyright  2002,2003,2004,2005,2006,2007 COLLARD Christophe
  * copyright  2002,2003,2004 CREUSE Emmanuel
- * copyright  2002,2003,2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2002,2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*! \class symmatrix
@@ -38,12 +38,12 @@
     \endhtmlonly
 
 
-    \authors copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006 Christophe COLLARD \n
+    \authors copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Christophe COLLARD \n
              copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004 Emmanuel CREUSE \n
-	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 1.4.6
-    \date 2002-2006
+	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
+	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+    \version 1.4.8
+    \date 2002-2007
     \bug none
     \warning none
 */
@@ -97,7 +97,7 @@ template <class T> class symmatrix : public virtual matrix<T>
     symmatrix (int, int, bool=true, T=0); // this constructor allocates memory
     symmatrix (const symmatrix<T>&);      // copy constructor
     symmatrix (symmatrix<T>*);            // copy constructor for temporary objects
-    //    symmatrix (const matrix<T>&);         // copy constructor
+    symmatrix (const matrix<T>&);         // cast constructor matrix -> symmatrix
 
     virtual int Columns () const {return nbColumns;}     // returns the # of columns
     virtual void assign  (int,int);  // assign memory without initilizing the symmetric matrix components to zero
@@ -185,26 +185,23 @@ template <class T> symmatrix<T>::symmatrix (symmatrix<T>* mat)
 }
 
 
-/*
 //---------------------------------------------------------------
 template <class T> symmatrix<T>::symmatrix (const matrix<T>& mat)
 //---------------------------------------------------------------
 {
-  assert (mat.nbRows && mat.nbColumns);
-  assert (mat.nbRows==mat.nbColumns);  // this matrix must be a squared in order to be symmetric
+  assert (mat.Rows() && mat.Columns());
+  assert (mat.Rows() == mat.Columns());  // this matrix must be a squared in order to be symmetric
 
-  mrows = new vector<T> [nbRows=mat.nbRows];
-  nbColumns = mat.nbColumns;
-  for (int i=1; i<=mat.nbRows; i++)
+  mrows = new vector<T> [nbRows=mat.Rows()];
+  nbColumns = mat.Columns();
+  for (int i=1; i<=nbRows; i++)
     { mrows[i-1] = i;
       for (int j=1; j<=i; j++)
-	{ assert (abs(mat(i,j)-mat(j,i))<epsilon); // needed by symmatrix = matrix
+ 	{ assert (abs(mat(i,j)-mat(j,i))<epsilon); // needed by symmatrix = matrix
 	  (*this)(i,j) = mat(i,j);
 	}
     }
-  return *this;
 }
-*/
 
 
 //------------------------------------------------------------------
