@@ -2,12 +2,12 @@
  *                 Mathematical Object Library                 *
  *      class tensor3 : declarations for 3rd order tensors     *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.5.2                   *
+ *                   GNU/linux version 0.5.6                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2004,2005,2006 COLLARD Christophe
- * copyright  2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2004,2005,2006,2007 COLLARD Christophe
+ * copyright  2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*! \class tensor3
@@ -36,11 +36,11 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006 Christophe COLLARD \n
-	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.5.2
-    \date 2004-2006
+    \author copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007 Christophe COLLARD \n
+	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
+	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+    \version 0.5.6
+    \date 2004-2007
     \bug none
     \warning none
 */
@@ -86,7 +86,6 @@ template <class T> class tensor3
     virtual int dim3 () const {return tsr[0].dim2();}    // returns the tensor 3rd component size : j
     virtual void create (int);          // partial memory allocation (don't use this function except if you know what you're doing !!)
     virtual void assign (int,int,int);  // allocates memory without initilizing the tensor components to zero (so use it with great care)
-    operator int () const {return size;}    // cast operator : tensor3 -> int
     friend bool operator ! (const tensor3<T>& t) {return !t.size;}
 
     virtual T&  operator () (int,int,int) const;        // returns the element Pk,ij : P(tensor2,line,column)
@@ -118,8 +117,10 @@ template <class T> class tensor3
     // overloads iostreams
     template <class M> friend ostream& operator << (ostream&, const tensor3<M>&);  // overloads output stream for tensors
     template <class M> friend istream& operator >> (istream&, const tensor3<M>&);  // overloads output stream for tensors
-    virtual void save (const char*); // writes to disk
-    virtual void read (const char*); // reads from disk
+    virtual void save (const char*);   // writes to disk
+    virtual void save (const string&); // writes to disk
+    virtual void read (const char*);   // reads from disk
+    virtual void read (const string&); // reads from disk
     tensor3<T>& approximation ();
 };
 
@@ -561,6 +562,12 @@ template <class T> istream& operator >> (istream& s, const tensor3<T>& tn)
 }
 
 
+/*!
+  \brief Writes\f$ 3^\text{rd} \f$ order tensor to hard disk.
+
+  \param filename path and filename
+*/
+
 //---------------------------------------------------------
 template <class T> void tensor3<T>::save (const char* path)
 //---------------------------------------------------------
@@ -574,6 +581,27 @@ template <class T> void tensor3<T>::save (const char* path)
 }
 
 
+/*!
+  \brief Writes \f$ 3^\text{rd} \f$ order tensor to hard disk.
+
+  \param filename path and filename
+*/
+
+//---------------------------------------------------------------
+template <class T> void tensor3<T>::save (const string& filename)
+//---------------------------------------------------------------
+{
+  const char *path = filename.c_str();
+  save (path);
+}
+
+
+/*!
+  \brief Reads \f$ 3^\text{rd} \f$ order tensor from hard disk.
+
+  \param filename path and filename
+*/
+
 //---------------------------------------------------------
 template <class T> void tensor3<T>::read (const char* path)
 //---------------------------------------------------------
@@ -587,6 +615,21 @@ template <class T> void tensor3<T>::read (const char* path)
 }
 
 
+/*!
+  \brief Reads \f$ 3^\text{rd} \f$ order tensor from hard disk.
+
+  \param filename path and filename
+*/
+
+//---------------------------------------------------------------
+template <class T> void tensor3<T>::read (const string& filename)
+//---------------------------------------------------------------
+{
+  const char *path = filename.c_str();
+  read (path);
+}
+
+
 //---------------------------------------------------------
 template <class T> tensor3<T>& tensor3<T>::approximation ()
 //---------------------------------------------------------
