@@ -2,12 +2,12 @@
  *                 Mathematical Object Library                 *
  *      class tensor4 : declarations for 4th order tensors     *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.6.0                   *
+ *                   GNU/linux version 0.6.8                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2004,2005,2006 COLLARD Christophe
- * copyright  2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2004,2005,2006,2007 COLLARD Christophe
+ * copyright  2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*! \class tensor4
@@ -36,11 +36,11 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006 Christophe COLLARD \n
-	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.6.0
-    \date 2004-2006
+    \author copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007 Christophe COLLARD \n
+	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
+	    copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+    \version 0.6.8
+    \date 2004-2007
     \bug none
     \warning none
 */
@@ -95,7 +95,6 @@ template <class T> class tensor4
     virtual int dim4 () const {return tsr[0].dim3();}    // returns the tensor 3rd component size : l
     virtual void create (int);              // partial memory allocation (don't use this function except if you know what you're doing !!)
     virtual void assign (int,int,int,int);  // allocates memory without initilizing the tensor components to zero
-    operator int () const {return size;}         // cast operator : tensor4 -> int
     friend bool operator ! (const tensor4<T>& t) {return !t.size;}
 
     virtual T&   operator () (int,int,int,int) const;    // returns the element Pijkl : P(tensor3,tensor2,line,column)
@@ -104,39 +103,42 @@ template <class T> class tensor4
     virtual tensor4<T>& operator = (tensor4<T>*);  // allocates the data from the right hand temporary object to the left hand object - no copy (deletes temporary object)
     virtual tensor4<T>& operator &= (const tensor4<T>&); // copies tensor4 without size check (use this operator with great care)
     virtual tensor4<T>& operator &= (tensor4<T>*); // allocates the data from the right hand temporary object to the left hand object (deletes temporary object) - no size check - no copy (use this operator with great care)
-    template <class M> friend tensor4<M> operator +  (const tensor4<M>&, const tensor4<M>&); // overloads operator + for 4th order tensors
-    template <class M> friend tensor4<M> operator -  (const tensor4<M>&, const tensor4<M>&); // overloads operator - for 4th order tensors
-    template <class M> friend M          operator |  (const tensor4<M>&, const tensor4<M>&); // T_ijkl  R_ijkl
-    template <class M> friend tensor4<M> operator || (const tensor4<M>&, const tensor4<M>&); // P_ijkl = T_ijpq R_pqkl
+    template <class Tf> friend tensor4<Tf> operator +  (const tensor4<Tf>&, const tensor4<Tf>&); // overloads operator + for 4th order tensors
+    template <class Tf> friend tensor4<Tf> operator -  (const tensor4<Tf>&, const tensor4<Tf>&); // overloads operator - for 4th order tensors
+    template <class Tf> friend Tf          operator |  (const tensor4<Tf>&, const tensor4<Tf>&); // T_ijkl  R_ijkl
+    template <class Tf> friend tensor4<Tf> operator || (const tensor4<Tf>&, const tensor4<Tf>&); // P_ijkl = T_ijpq R_pqkl
     tensor4<T>& operator += (const tensor4<T>&);     // overloads += operator for tensors
     tensor4<T>& operator -= (const tensor4<T>&);     // overloads -= operator for tensors
-    template <class M> friend bool operator == (const tensor4<M>&, const tensor4<M>&);  // compares 2 tensors
-    template <class M> friend bool operator != (const tensor4<M>&, const tensor4<M>&);
+    template <class Tf> friend bool operator == (const tensor4<Tf>&, const tensor4<Tf>&);  // compares 2 tensors
+    template <class Tf> friend bool operator != (const tensor4<Tf>&, const tensor4<Tf>&);
     // operations with scalars
     tensor4<T>& operator *= (const T&);
-    template <class M> friend tensor4<M> operator * (const tensor4<M>&, const M&);
-    template <class M> friend tensor4<M> operator * (const M&, const tensor4<M>&);
+    template <class Tf> friend tensor4<Tf> operator * (const tensor4<Tf>&, const Tf&);
+    template <class Tf> friend tensor4<Tf> operator * (const Tf&, const tensor4<Tf>&);
     // operations withs vectors
-    template <class M> friend tensor3<M> operator * (const tensor4<M>&, const vector<M>&);   // P_ijk = T_ijkl * V_l
-    template <class M> friend tensor3<M> operator * (const vector<M>&, const tensor4<M>&);   // P_jkl = T_ijkl * V_i
-    template <class M> friend tensor3<M> operator | (const tensor4<M>&, const vector<M>&);   // P_ijl = T_ijkl * V_k
-    template <class M> friend tensor3<M> operator | (const vector<M>&, const tensor4<M>&);   // P_ikl = T_ijkl * V_j
-    template <class M> friend tensor3<M> tensor_sum (const tensor4<M>&, const vector<M>&, int); // P = T : v
+    template <class Tf> friend tensor3<Tf> operator * (const tensor4<Tf>&, const vector<Tf>&);   // P_ijk = T_ijkl * V_l
+    template <class Tf> friend tensor3<Tf> operator * (const vector<Tf>&, const tensor4<Tf>&);   // P_jkl = T_ijkl * V_i
+    template <class Tf> friend tensor3<Tf> operator | (const tensor4<Tf>&, const vector<Tf>&);   // P_ijl = T_ijkl * V_k
+    template <class Tf> friend tensor3<Tf> operator | (const vector<Tf>&, const tensor4<Tf>&);   // P_ikl = T_ijkl * V_j
+    template <class Tf> friend tensor3<Tf> tensor_sum (const tensor4<Tf>&, const vector<Tf>&, int); // P = T : v
     // operation with tensor2 (2nd order tensor)
-    template <class M> friend tensor2<M> operator || (const tensor4<M>&, const tensor2<M>&);  // P_ij = T_ijkl * M_kl
-    template <class M> friend tensor2<M> operator || (const tensor2<M>&, const tensor4<M>&);  // P_kl = M_ij * T_ijkl
-    template <class M> friend tensor4<M> operator ^  (const tensor2<M>&, const tensor2<M>&);  // T_ijkl = M1_ij M2_kl
+    template <class Tf> friend tensor2<Tf> operator || (const tensor4<Tf>&, const tensor2<Tf>&);  // P_ij = T_ijkl * M_kl
+    template <class Tf> friend tensor2<Tf> operator || (const tensor2<Tf>&, const tensor4<Tf>&);  // P_kl = M_ij * T_ijkl
+    template <class Tf> friend tensor4<Tf> operator ^  (const tensor2<Tf>&, const tensor2<Tf>&);  // T_ijkl = M1_ij M2_kl
     // operation with 3rd order tensor
-    template <class M> friend tensor4<M> operator ^  (const tensor3<M>&, const tensor3<M>&); // T_ijkl = Pn,ij * Rn,kl = P_ij[n] * R_kl[n]
-    template <class M> friend tensor3<M> operator || (const tensor3<M>&, const tensor4<M>&);  // P_n,ij = R_n,kl T_klij
-    template <class M> friend tensor3<M> operator || (const tensor4<M>&, const tensor3<M>&);  // P_n,ij = T_ijkl R_n,kl
+    template <class Tf> friend tensor4<Tf> operator ^  (const tensor3<Tf>&, const tensor3<Tf>&); // T_ijkl = Pn,ij * Rn,kl = P_ij[n] * R_kl[n]
+    template <class Tf> friend tensor3<Tf> operator || (const tensor3<Tf>&, const tensor4<Tf>&);  // P_n,ij = R_n,kl T_klij
+    template <class Tf> friend tensor3<Tf> operator || (const tensor4<Tf>&, const tensor3<Tf>&);  // P_n,ij = T_ijkl R_n,kl
 
     template <class Tf> friend tensor4<Tf> Id4s (int);  // returns identity tensor for symmetric tensors : Tijkl = Tjikl = Tijlk
+    template <class Tf> friend tensor4<Tf> change_basis (const matrix<Tf>&, const tensor4<Tf>&);
 
-    template <class M> friend ostream& operator << (ostream&, const tensor4<M>&);  // overloads output stream for tensors
-    template <class M> friend istream& operator >> (istream&, const tensor4<M>&);  // overloads output stream for tensors
-    virtual void save (const char*); // writes to disk
-    virtual void read (const char*); // reads from disk
+    template <class Tf> friend ostream& operator << (ostream&, const tensor4<Tf>&);  // overloads output stream for tensors
+    template <class Tf> friend istream& operator >> (istream&, const tensor4<Tf>&);  // overloads output stream for tensors
+    virtual void save (const char*);   // writes to disk
+    virtual void save (const string&); // writes to disk
+    virtual void read (const char*);   // reads from disk
+    virtual void read (const string&);   // reads from disk
     tensor4<T>& approximation ();
 };
 
@@ -330,36 +332,36 @@ template <class T> tensor4<T>& tensor4<T>::operator &= (tensor4<T>* tn)
 }
 
 
-//-----------------------------------------------------------------------------------
-template <class T> tensor4<T> operator + (const tensor4<T>& t1, const tensor4<T>& t2)
-//-----------------------------------------------------------------------------------
+//---------------------------------------------------------------------------------------
+template <class Tf> tensor4<Tf> operator + (const tensor4<Tf>& t1, const tensor4<Tf>& t2)
+//---------------------------------------------------------------------------------------
 {
+  assert (t1.size);
   assert (t1.dim1()==t2.dim1()); // tensors must have the same size
-  assert(t1.dim1());
-  tensor4<T> t = t1;
+  tensor4<Tf> t = t1;
   return t+=t2;
 }
 
 
-//-----------------------------------------------------------------------------------
-template <class T> tensor4<T> operator - (const tensor4<T>& t1, const tensor4<T>& t2)
-//-----------------------------------------------------------------------------------
+//---------------------------------------------------------------------------------------
+template <class Tf> tensor4<Tf> operator - (const tensor4<Tf>& t1, const tensor4<Tf>& t2)
+//---------------------------------------------------------------------------------------
 {
+  assert (t1.size);
   assert (t1.dim1()==t2.dim1()); // tensors must have the same size
-  assert(t1.dim1());
-  tensor4<T> t = t1;
+  tensor4<Tf> t = t1;
   return t-=t2;
 }
 
 
-//--------------------------------------------------------------------------
-template <class T> T operator | (const tensor4<T>& t1, const tensor4<T>& t2)
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+template <class Tf> Tf operator | (const tensor4<Tf>& t1, const tensor4<Tf>& t2)
+//------------------------------------------------------------------------------
 {
+  assert (t1.size);
   assert (t1.size==t2.size); // tensors must have the same size
-  assert(t1.size);
 
-  T sum=0;
+  Tf sum=0;
   for (int i=1; i<=t1.size; i++)
     sum += (t1[i] | t2[i]);
 
@@ -367,13 +369,14 @@ template <class T> T operator | (const tensor4<T>& t1, const tensor4<T>& t2)
 }
 
 
-//------------------------------------------------------------------------------------
-template <class T> tensor4<T> operator || (const tensor4<T>& t1, const tensor4<T>& t2)
-//------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------
+template <class Tf> tensor4<Tf> operator || (const tensor4<Tf>& t1, const tensor4<Tf>& t2)
+//----------------------------------------------------------------------------------------
 {
+  assert (t1.size && t2.size);
   assert ( (t1.dim3() == t2.dim1()) && (t1.dim4() == t2.dim2()) );
 
-  tensor4<T> t3 (t1.dim1(),t1.dim2(),t2.dim3(),t2.dim4());
+  tensor4<Tf> t3 (t1.dim1(),t1.dim2(),t2.dim3(),t2.dim4());
   for (int i=1; i<=t1.dim1(); i++)
     for (int j=1; j<=t1.dim2(); j++)
       for (int p=1; p<=t1.dim3(); p++)
@@ -410,9 +413,9 @@ template <class T> tensor4<T>& tensor4<T>::operator -= (const tensor4<T>& ts)
 }
 
 
-//------------------------------------------------------------------------------
-template <class T> bool operator == (const tensor4<T>& t1, const tensor4<T>& t2)
-//------------------------------------------------------------------------------
+//---------------------------------------------------------------------------------
+template <class Tf> bool operator == (const tensor4<Tf>& t1, const tensor4<Tf>& t2)
+//---------------------------------------------------------------------------------
 {
   assert (t1.size);
   int result=(t1.size==t2.size);
@@ -422,9 +425,9 @@ template <class T> bool operator == (const tensor4<T>& t1, const tensor4<T>& t2)
 }
 
 
-//------------------------------------------------------------------------------
-template <class T> bool operator != (const tensor4<T>& t1, const tensor4<T>& t2)
-//------------------------------------------------------------------------------
+//---------------------------------------------------------------------------------
+template <class Tf> bool operator != (const tensor4<Tf>& t1, const tensor4<Tf>& t2)
+//---------------------------------------------------------------------------------
 {
   return !(t1 == t2);
 }
@@ -441,34 +444,34 @@ template <class T> tensor4<T>& tensor4<T>::operator *= (const T& elt)
 }
 
 
-//---------------------------------------------------------------------------
-template <class T> tensor4<T> operator * (const tensor4<T>& ts, const T& elt)
-//---------------------------------------------------------------------------
+//-------------------------------------------------------------------------------
+template <class Tf> tensor4<Tf> operator * (const tensor4<Tf>& ts, const Tf& elt)
+//-------------------------------------------------------------------------------
 {
   assert (ts.size);
-  tensor4<T> tr = ts;
+  tensor4<Tf> tr = ts;
   return  tr *= elt;
 }
 
 
-//---------------------------------------------------------------------------
-template <class T> tensor4<T> operator * (const T& elt, const tensor4<T>& ts)
-//---------------------------------------------------------------------------
+//-------------------------------------------------------------------------------
+template <class Tf> tensor4<Tf> operator * (const Tf& elt, const tensor4<Tf>& ts)
+//-------------------------------------------------------------------------------
 {
   assert (ts.size);
-  tensor4<T> tr = ts;
+  tensor4<Tf> tr = ts;
   return  tr *= elt;
 }
 
 
-//---------------------------------------------------------------------------------
-template <class T> tensor3<T> operator * (const tensor4<T>& ts, const vector<T>& v)
-//---------------------------------------------------------------------------------
+//-------------------------------------------------------------------------------------
+template <class Tf> tensor3<Tf> operator * (const tensor4<Tf>& ts, const vector<Tf>& v)
+//-------------------------------------------------------------------------------------
 {
   assert (v.dim());
   assert (v.dim() == ts.dim4());
 
-  tensor3<T> ts3;
+  tensor3<Tf> ts3;
   ts3.create(ts.dim1());
   for (int i=1; i<=ts.size; i++)
     ts3[i] =& (ts[i] * v);
@@ -477,27 +480,27 @@ template <class T> tensor3<T> operator * (const tensor4<T>& ts, const vector<T>&
 }
 
 
-//---------------------------------------------------------------------------------
-template <class T> tensor3<T> operator * (const vector<T>& v, const tensor4<T>& ts)
-//---------------------------------------------------------------------------------
+//-------------------------------------------------------------------------------------
+template <class Tf> tensor3<Tf> operator * (const vector<Tf>& v, const tensor4<Tf>& ts)
+//-------------------------------------------------------------------------------------
 {
   assert (v.dim());
   assert (v.dim() == ts.dim1());
-  tensor3<T> tr(ts.dim2(),ts.dim3(),ts.dim4());
+  tensor3<Tf> tr(ts.dim2(),ts.dim3(),ts.dim4());
   for (int i=1; i<=ts.size; i++)
     tr += v[i] * ts[i];
   return tr;
 }
 
 
-//---------------------------------------------------------------------------------
-template <class T> tensor3<T> operator | (const tensor4<T>& ts, const vector<T>& v)
-//---------------------------------------------------------------------------------
+//-------------------------------------------------------------------------------------
+template <class Tf> tensor3<Tf> operator | (const tensor4<Tf>& ts, const vector<Tf>& v)
+//-------------------------------------------------------------------------------------
 {
   assert (v.dim());
   assert (v.dim() == ts.dim3());
 
-  tensor3<T> tr(ts.dim1(),ts.dim2(),ts.dim4());
+  tensor3<Tf> tr(ts.dim1(),ts.dim2(),ts.dim4());
   for (int i=1; i<=ts.size; i++)
     tr[i] += ts[i] | v;
 
@@ -505,14 +508,14 @@ template <class T> tensor3<T> operator | (const tensor4<T>& ts, const vector<T>&
 }
 
 
-//---------------------------------------------------------------------------------
-template <class T> tensor3<T> operator | (const vector<T>& v, const tensor4<T>& ts)
-//---------------------------------------------------------------------------------
+//-------------------------------------------------------------------------------------
+template <class Tf> tensor3<Tf> operator | (const vector<Tf>& v, const tensor4<Tf>& ts)
+//-------------------------------------------------------------------------------------
 {
   assert (v.dim());
   assert (v.dim() == ts.dim2());
 
-  tensor3<T> tr(ts.dim1(),ts.dim3(),ts.dim4());
+  tensor3<Tf> tr(ts.dim1(),ts.dim3(),ts.dim4());
   for (int i=1; i<=ts.size; i++)
     tr[i] += v * ts[i];
 
@@ -520,13 +523,13 @@ template <class T> tensor3<T> operator | (const vector<T>& v, const tensor4<T>&
 }
 
 
-//----------------------------------------------------------------------------------------
-template <class T> tensor3<T> tensor_sum (const tensor4<T>& ts, const vector<T>& v, int i)
-//----------------------------------------------------------------------------------------
+//--------------------------------------------------------------------------------------------
+template <class Tf> tensor3<Tf> tensor_sum (const tensor4<Tf>& ts, const vector<Tf>& v, int i)
+//--------------------------------------------------------------------------------------------
 {
   assert (i>=1 && i<=4);
 
-  tensor3<T> tr;
+  tensor3<Tf> tr;
   if (i==1) tr =& (v*ts);
   else if (i==2) tr =& (v|ts);
        else if (i==3) tr =& (ts|v);
@@ -536,14 +539,15 @@ template <class T> tensor3<T> tensor_sum (const tensor4<T>& ts, const vector<T>&
 }
 
 
-//------------------------------------------------------------------------------------
-template <class T> tensor2<T> operator || (const tensor4<T>& t, const tensor2<T>& mat)
-//------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------
+template <class Tf> tensor2<Tf> operator || (const tensor4<Tf>& t, const tensor2<Tf>& mat)
+//----------------------------------------------------------------------------------------
 {
+  assert (t.size);
   assert (t.dim3() == mat.Rows());
   assert (t.dim4() == mat.Columns());
 
-  tensor2<T> mat_result(t.dim1(),t.dim2(),false);
+  tensor2<Tf> mat_result(t.dim1(),t.dim2(),false);
   for (int i=1; i<=t.dim1(); i++)
     for (int j=1; j<=t.dim2(); j++)
       mat_result(i,j) = t[i][j] | mat;
@@ -552,14 +556,15 @@ template <class T> tensor2<T> operator || (const tensor4<T>& t, const tensor2<T>
 }
 
 
-//------------------------------------------------------------------------------------
-template <class T> tensor2<T> operator || (const tensor2<T>& mat, const tensor4<T>& t)
-//------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------
+template <class Tf> tensor2<Tf> operator || (const tensor2<Tf>& mat, const tensor4<Tf>& t)
+//----------------------------------------------------------------------------------------
 {
+  assert (t.size);
   assert (t.dim1() == mat.Rows());
   assert (t.dim2() == mat.Columns());
 
-  tensor2<T> mat_result(t.dim3(),t.dim4());
+  tensor2<Tf> mat_result(t.dim3(),t.dim4());
   for (int i=1; i<=t.dim1(); i++)
     for (int j=1; j<=t.dim2(); j++)
       for (int k=1; k<=t.dim3(); k++)
@@ -570,13 +575,13 @@ template <class T> tensor2<T> operator || (const tensor2<T>& mat, const tensor4<
 }
 
 
-//---------------------------------------------------------------------------------------
-template <class T> tensor4<T> operator ^ (const tensor2<T>& mat1, const tensor2<T>& mat2)
-//---------------------------------------------------------------------------------------
+//-------------------------------------------------------------------------------------------
+template <class Tf> tensor4<Tf> operator ^ (const tensor2<Tf>& mat1, const tensor2<Tf>& mat2)
+//-------------------------------------------------------------------------------------------
 {
   assert (mat1.Rows() && mat1.Columns() && mat2.Rows() && mat2.Columns());
 
-  tensor4<T> tsr(mat1.Rows(),mat1.Columns(),mat2.Rows(),mat2.Columns(),false);
+  tensor4<Tf> tsr(mat1.Rows(),mat1.Columns(),mat2.Rows(),mat2.Columns(),false);
   for (int i=1; i<=mat1.Rows(); i++)
     for (int j=1; j<=mat1.Columns(); j++)
       for (int k=1; k<=mat2.Rows(); k++)
@@ -587,26 +592,27 @@ template <class T> tensor4<T> operator ^ (const tensor2<T>& mat1, const tensor2<
 }
 
 
-//-----------------------------------------------------------------------------------
-template <class T> tensor4<T> operator ^ (const tensor3<T>& t1, const tensor3<T>& t2)
-//-----------------------------------------------------------------------------------
+//---------------------------------------------------------------------------------------
+template <class Tf> tensor4<Tf> operator ^ (const tensor3<Tf>& t1, const tensor3<Tf>& t2)
+//---------------------------------------------------------------------------------------
 {
+  assert (t1.dim1());
   assert (t1.dim1() == t2.dim1());
-  tensor4<T> t4(t1.dim2(), t1.dim3(), t2.dim2(), t2.dim3());
+  tensor4<Tf> t4(t1.dim2(), t1.dim3(), t2.dim2(), t2.dim3());
   for (int n=1; n<=t1.dim1(); n++)
     t4 += (t1[n] ^ t2[n]);
   return t4;
 }
 
 
-//------------------------------------------------------------------------------------
-template <class T> tensor3<T> operator || (const tensor3<T>& t3, const tensor4<T>& t4)
-//------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------
+template <class Tf> tensor3<Tf> operator || (const tensor3<Tf>& t3, const tensor4<Tf>& t4)
+//----------------------------------------------------------------------------------------
 {
   assert (t3.dim1() && t4.dim1());
   assert ( (t3.dim2() == t4.dim1()) && (t3.dim3() == t4.dim2()) );
 
-  tensor3<T> ts;
+  tensor3<Tf> ts;
   ts.create(t3.dim1());
 
   for (int n=1; n<=t3.dim1(); n++)
@@ -616,14 +622,14 @@ template <class T> tensor3<T> operator || (const tensor3<T>& t3, const tensor4<T
 }
 
 
-//------------------------------------------------------------------------------------
-template <class T> tensor3<T> operator || (const tensor4<T>& t4, const tensor3<T>& t3)
-//------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------
+template <class Tf> tensor3<Tf> operator || (const tensor4<Tf>& t4, const tensor3<Tf>& t3)
+//----------------------------------------------------------------------------------------
 {
   assert (t3.dim1() && t4.dim1());
   assert ( (t3.dim2() == t4.dim3()) && (t3.dim3() == t4.dim4()) );
 
-  tensor3<T> ts;
+  tensor3<Tf> ts;
   ts.create(t3.dim1());
 
   for (int n=1; n<=t3.dim1(); n++)
@@ -650,10 +656,42 @@ template <class Tf> tensor4<Tf> Id4s (int n)
 }
 
 
-//------------------------------------------------------------------------
-template <class T> ostream& operator << (ostream& s, const tensor4<T>& tn)
-//------------------------------------------------------------------------
+/*!
+  \brief Computes the change of basis for a \f$ 4^{th} \f$ order tensor.
+
+  \f$ \displaystyle T^\prime_{pqmn} = P_{pi} P_{qj} P_{mk} P_{nl} T_{ijkl} \f$. \n
+  \param P change of basis matrix
+  \param tsr tensor T in the old basis
+  \return \f$ T^\prime \f$ tensor in the new basis
+*/
+
+//----------------------------------------------------------------------------------------
+template <class Tf> tensor4<Tf> change_basis (const matrix<Tf>& P, const tensor4<Tf>& tsr)
+//----------------------------------------------------------------------------------------
 {
+  assert ((P.Rows() ==3) && (P.Columns() == 3));
+  assert (tsr.size == 3 && tsr.dim2()==3 && tsr.dim3() && tsr.dim4()==3);
+
+  tensor4<Tf> Tsr(3);
+  for (int p=1; p<=3; p++)
+    for (int q=1; q<=3; q++)
+      for (int m=1; m<=3; m++)
+	for (int n=1; n<=3; n++)
+	  for (int i=1; i<=3; i++)
+	    for (int j=1; j<=3; j++)
+	      for (int k=1; k<=3; k++)
+		for (int l=1; l<=3; l++)
+		  Tsr(p,q,m,n) += P(p,i) * P(q,j) * P(m,k) * P(n,l) * tsr(i,j,k,l);
+
+  return Tsr;
+}
+
+
+//--------------------------------------------------------------------------
+template <class Tf> ostream& operator << (ostream& s, const tensor4<Tf>& tn)
+//--------------------------------------------------------------------------
+{
+  assert (tn.size);
   for (int i=1; i<=tn.size; i++)
       s << tn[i];
   s << endl;
@@ -661,9 +699,9 @@ template <class T> ostream& operator << (ostream& s, const tensor4<T>& tn)
 }
 
 
-//------------------------------------------------------------------------
-template <class T> istream& operator >> (istream& s, const tensor4<T>& tn)
-//------------------------------------------------------------------------
+//--------------------------------------------------------------------------
+template <class Tf> istream& operator >> (istream& s, const tensor4<Tf>& tn)
+//--------------------------------------------------------------------------
 {
   assert (tn.size);
 
@@ -674,6 +712,12 @@ template <class T> istream& operator >> (istream& s, const tensor4<T>& tn)
 }
 
 
+/*!
+  \brief Writes \f$ 4^\text{th} \f$ order tensor to hard disk.
+
+  \param filename path and filename
+*/
+
 //---------------------------------------------------------
 template <class T> void tensor4<T>::save (const char* path)
 //---------------------------------------------------------
@@ -687,6 +731,27 @@ template <class T> void tensor4<T>::save (const char* path)
 }
 
 
+/*!
+  \brief Writes \f$ 4^\text{th} \f$ order tensor to hard disk.
+
+  \param filename path and filename
+*/
+
+//---------------------------------------------------------------
+template <class T> void tensor4<T>::save (const string& filename)
+//---------------------------------------------------------------
+{
+  const char *path = filename.c_str();
+  save (path);
+}
+
+
+/*!
+  \brief Reads \f$ 4^\text{th} \f$ order tensor from hard disk.
+
+  \param filename path and filename
+*/
+
 //---------------------------------------------------------
 template <class T> void tensor4<T>::read (const char* path)
 //---------------------------------------------------------
@@ -700,6 +765,21 @@ template <class T> void tensor4<T>::read (const char* path)
 }
 
 
+/*!
+  \brief Reads \f$ 4^\text{th} \f$ order tensor from hard disk.
+
+  \param filename path and filename
+*/
+
+//---------------------------------------------------------------
+template <class T> void tensor4<T>::read (const string& filename)
+//---------------------------------------------------------------
+{
+  const char *path = filename.c_str();
+  read (path);
+}
+
+
 //---------------------------------------------------------
 template <class T> tensor4<T>& tensor4<T>::approximation ()
 //---------------------------------------------------------
