@@ -2,14 +2,14 @@
  *                 Mathematical Object Library                 *
  *           class vector : declaration for vectors            *
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 1.7.8	               *
+ *	             GNU/linux version 1.8.22	               *
  *            software under General Public License            *
  ***************************************************************
- * copyright  1994,1995,1996,1999,2000,2001,2002,2003,2004,2005,2006 COLLARD Christophe
+ * copyright  1994,1995,1996,1999,2000,2001,2002,2003,2004,2005,2006,2007 COLLARD Christophe
  * copyright  2002,2003,2004 CREUSE Emmanuel
  * copyright  2003,2004 MERCIER Denis
- * copyright  2002,2003,2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2002,2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*! \class vector
@@ -41,13 +41,13 @@
     A vector is defined by its size and a pointer on the table of its coordinates. \n
     When the size of a vector is zero there is no table of coordinates attached to the pointer.
 
-    \authors copyright \htmlonly &#169; \endhtmlonly 1994, 1995, 1996, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Christophe COLLARD \n
+    \authors copyright \htmlonly &#169; \endhtmlonly 1994, 1995, 1996, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Christophe COLLARD \n
              copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004 Emmanuel CREUSE \n
 	     copyright \htmlonly &#169; \endhtmlonly 2003, 2004 Denis MERCIER \n
-	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 1.7.8
-    \date 1994-2006
+	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
+	     copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+    \version 1.8.2
+    \date 1994-2007
     \bug none
     \warning none
 */
@@ -112,7 +112,6 @@ template <class T> class vector
 
     void assign (int);  // allocates memory for the vector but doen't initilize to zero its components (use it with great care)
     int dim () const {return size;}       // returns the vector size
-    operator int () const {return size;}  // cast operator : vector -> int
     friend bool operator ! (const vector<T>& v) {return !v.size;}
 
     T& operator [] (int) const;     // returns the address of an element
@@ -140,7 +139,9 @@ template <class T> class vector
     template <class Tf> friend istream& operator >> (istream&, const vector<Tf>&);
 // i/o disk
     void save (const char*);
+    void save (const string&);
     void read (const char*);
+    void read (const string&);
 // vector operations
     virtual long double norm () const;  // computes the norm of a vector
     virtual T norminf () const;         // computes the infinite norm
@@ -586,6 +587,23 @@ template <class Tf> Tf operator * (const vector<Tf>& a, const vector<Tf>& b)
 }
 
 
+/*!
+  \brief Division by a vector of size 1.
+
+  Computes the division of a vector \f$ \boldsymbol{a} = (a_i) \f$ by a scalar stored as a vector \f$ \boldsymbol{b} = (b_1) \f$ :
+  \f$ c_i = a_i / b_1 \f$, where c is a vector.
+  \param vector a
+  \param vector b
+  \return \f$ c = a/b_1 \f$
+  \n\n
+  \f$ \textbf{Example :} \f$ \n
+  \f$ \textbf{vector$<$double$>$ w(4), z(1);} \; \textit{Defines 2 vectors with type double and allocates memory for their coordinates.} \f$ \n
+  \f$ \textbf{vector$<$double$>$ v;} \; \textit{Defines a vector with type double.} \f$ \n
+  \f$ \textbf{z[1]=1.23;} \; \textit{Stores the coordinates of "z" (see} \f$ \ref vector:operator[](int) \f$\textit{).} \f$ \n
+  \f$ \textbf{w[1]=-1.45; w[3]=0.436; w[4]=5.75;} \; \textit{Stores the coordinates of "w" (see} \f$ \ref vector:operator[](int) \f$\textit{).} \f$ \n
+  \f$ \textbf{v = w / z;} \; \textit{Stores "w/z[1]" in v.} \f$ \n
+*/
+
 //----------------------------------------------------------------------------------
 template <class Tf> vector<Tf> operator / (const vector<Tf>& a, const vector<Tf>& b)
 //----------------------------------------------------------------------------------
@@ -694,6 +712,59 @@ template <class Tf> istream& operator >> (istream& s, const vector<Tf>& v)
 }
 
 
+/*!
+  \brief Writes vector to hard disk.
+
+  \param path path and filename
+  \n\n
+  \f$ \textbf{Example :} \f$ \n
+  \f$ \textbf{vector$<$double$>$ z(4);} \; \textit{Defines a vector with type double and with 4 coordinates initialized to 0.} \f$ \n
+  \f$ \textbf{z.save("vector.res");} \; \textit{Writes vector to disk. The filename is "vector.res".} \f$ \n
+*/
+
+//--------------------------------------------------------
+template <class T> void vector<T>::save (const char* path)
+//--------------------------------------------------------
+{
+  assert (size);
+  ofstream file(path, ios::out);
+  assert (!file.fail());
+  file << *this;
+  file.close();
+}
+
+
+/*!
+  \brief Writes vector to hard disk.
+
+  \param filename path and filename
+  \n\n
+  \f$ \textbf{Example :} \f$ \n
+  \f$ \textbf{vector$<$double$>$ z(4);} \; \textit{Defines a vector with type double and with 4 coordinates initialized to 0.} \f$ \n
+  \f$ \textbf{string name="vector";} \; \textit{Defines and initializes a string to "vector".} \f$ \n
+  \f$ \textbf{name += ".res";} \; \textit{Adds ".res" to string.} \f$ \n
+  \f$ \textbf{z.save(name);} \; \textit{Writes vector to disk. The filename is "vector.res".} \f$ \n
+*/
+
+//--------------------------------------------------------------
+template <class T> void vector<T>::save (const string& filename)
+//--------------------------------------------------------------
+{
+  const char *path = filename.c_str();
+  save (path);
+}
+
+
+/*!
+  \brief Reads vector from hard disk.
+
+  \param path path and filename
+  \n\n
+  \f$ \textbf{Example :} \f$ \n
+  \f$ \textbf{vector$<$double$>$ z(4);} \; \textit{Defines a vector with type double and with 4 coordinates initialized to 0.} \f$ \n
+  \f$ \textbf{z.read("vector.res");} \; \textit{Reads vector coordinates from disk. The filename is "vector.res".} \f$ \n
+*/
+
 //--------------------------------------------------------
 template <class T> void vector<T>::read (const char* path)
 //--------------------------------------------------------
@@ -706,15 +777,24 @@ template <class T> void vector<T>::read (const char* path)
 }
 
 
-//--------------------------------------------------------
-template <class T> void vector<T>::save (const char* path)
-//--------------------------------------------------------
+/*!
+  \brief Reads vector from hard disk.
+
+  \param filename path and filename
+  \n\n
+  \f$ \textbf{Example :} \f$ \n
+  \f$ \textbf{vector$<$double$>$ z(4);} \; \textit{Defines a vector with type double and with 4 coordinates initialized to 0.} \f$ \n
+  \f$ \textbf{string name="vector";} \; \textit{Defines and initializes a string to "vector".} \f$ \n
+  \f$ \textbf{name += ".res";} \; \textit{Adds ".res" to string.} \f$ \n
+  \f$ \textbf{z.read(name);} \; \textit{Reads vector coordinates from disk. The filename is "vector.res".} \f$ \n
+*/
+
+//--------------------------------------------------------------
+template <class T> void vector<T>::read (const string& filename)
+//--------------------------------------------------------------
 {
-  assert (size);
-  ofstream file(path, ios::out);
-  assert (!file.fail());
-  file << *this;
-  file.close();
+  const char *path = filename.c_str();
+  read (path);
 }
 
 
