@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 0.2.8                   *
+ *	             GNU/linux version 0.3.2                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006 COLLARD Christophe
- * copyright  2003,2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2003,2004,2005,2006,2007 COLLARD Christophe
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*
@@ -48,19 +48,23 @@
 #endif
 
 #if !defined(__MATRIX_H)
-#include "../../MOL++/matrix.h"
+#include "MOL++/matrix.h"
 #endif
 
 #if !defined(__TENSORS4_H)
-#include "../../MOL++/tensors4.h"
+#include "MOL++/tensors4.h"
+#endif
+
+#if !defined(__SYMTENSORS2_H)
+#include "MOL++/symtensors2.h"
 #endif
 
 #if !defined(__CONVERSION_TOOLS_H)
-#include "../../MOL++/conversion tools.h"
+#include "MOL++/conversion tools.h"
 #endif
 
 #if !defined(__AFFICHE_H)
-#include "affiche.h"
+#include "tests/affiche.h"
 #endif
 
 
@@ -79,9 +83,8 @@ int test_conversion_tools (int detail)
   if (detail) affiche("matrix2vector", v==matrix2vector(mat));
   else result *= (v==matrix2vector(mat));
 
-  if (detail) affiche("vector2matrix", mat==vector2matrix(matrix2vector(mat),3,27) && ((tensor2<float>)mat|(tensor2<float>)mat)==v*v);
-  else result *= (mat==vector2matrix(matrix2vector(mat),3,27) && ((tensor2<float>)mat|(tensor2<float>)mat)==v*v);
-
+  if (detail) affiche("vector2matrix", mat==vector2matrix(matrix2vector(mat),3,27) && (mat|mat)==v*v);
+  else result *= (mat==vector2matrix(matrix2vector(mat),3,27) && (mat|mat)==v*v);
 
   tensor4<float> tsr(3,27,5,8);
   matrix<float> mat2(5,8);
@@ -103,7 +106,7 @@ int test_conversion_tools (int detail)
   for (int i=1; i<=4; i++)
     for (int j=i; j<=4; j++)
       t2sr (i,j) = t2sr(j,i) = i*pi()+2*j;
-  vector<long double>  v2sr = symtensor2vector(t2sr);
+  vector<long double>  v2sr = symtensor2vector((symtensor2<long double>)t2sr);
   if (detail) affiche("symtensor2vector", abs( (t2sr|t2sr) - v2sr*v2sr) < epsilon);
   else result *= (abs( (t2sr|t2sr) - v2sr*v2sr) < epsilon);
 
@@ -128,7 +131,7 @@ int test_conversion_tools (int detail)
       { if (i<=5 && j<=5) N(i,j) = N(j,i) = pi() * i - j;
 	R(i,j) = R(j,i) = i / (1.*j);
       }
-  vector<long double> vn =& symtensor2vector(N), vr =& symtensor2vector(R);
+  vector<long double> vn =& symtensor2vector((symtensor2<long double>) N), vr =& symtensor2vector((symtensor2<long double>) R);
   //  cout << (ts||R);
   //  cout << vector2symtensor(mts*vr);
   if (detail) affiche("symtensor2matrix", abs((N | (ts || R)) - vn * mts * vr) < 3*epsilon && (ts||R)==vector2symtensor(mts*vr) && symtensor2matrix(ts||st) == mts*mst);
