@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.1.8                   *
+ *                   GNU/linux version 0.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2004,2005,2006 COLLARD Christophe
- * copyright  2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2004,2005,2006,2007 COLLARD Christophe
+ * copyright  2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*
@@ -40,23 +40,23 @@
 #endif
 
 #if !defined(__VECTORS_H)
-#include "../../MOL++/vectors.h"
+#include "MOL++/vectors.h"
 #endif
 
 #if !defined(__FUNCTIONS_H)
-#include "../../MOL++/functions.h"
+#include "MOL++/functions.h"
 #endif
 
 #if !defined(__POLYNOMS_H)
-#include "../../MOL++/polynoms.h"
+#include "MOL++/polynoms.h"
 #endif
 
 #if !defined(__INTEGRATION_H)
-#include "../../MOL++/integration.h"
+#include "MOL++/integration.h"
 #endif
 
 #if !defined(__AFFICHE_H)
-#include "../affiche.h"
+#include "tests/affiche.h"
 #endif
 
 
