@@ -1,12 +1,12 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.3.1                   *
+ *                   GNU/linux version 0.3.3                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006 COLLARD Christophe
+ * copyright  2003,2004,2005,2006,2007 COLLARD Christophe
  * copyright  2003 CREUSE Emmanuel
- * copyright  2003,2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*
@@ -53,23 +53,23 @@
 #endif
 
 #if !defined(__VECTORS_H)
-#include "../../MOL++/vectors.h"
+#include "MOL++/vectors.h"
 #endif
 
 #if !defined(__MATRIX_H)
-#include "../../MOL++/matrix.h"
+#include "MOL++/matrix.h"
 #endif
 
 #if !defined(__LINEAR_SYSTEMS_H)
-#include "../../MOL++/linear systems.h"
+#include "MOL++/linear systems.h"
 #endif
 
 #if !defined(__SP_MATRIX_H)
-#include "../../MOL++/spmatrix.h"
+#include "MOL++/spmatrix.h"
 #endif
 
 #if !defined(__AFFICHE_h)
-#include "../affiche.h"
+#include "tests/affiche.h"
 #endif
 
 //==================================
