@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.1.8                   *
+ *                   GNU/linux version 0.2.4                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2004,2005,2006 COLLARD Christophe
- * copyright  2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2004,2005,2006,2007, 2008 COLLARD Christophe
+ * copyright  2004,2005,2006,2007, 2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*
@@ -40,24 +40,24 @@
 #endif
 
 #if !defined(__AFFICHE_h)
-#include "../affiche.h"
+#include "tests/affiche.h"
 #endif
 
 #if !defined(__PARAMETERS_H)
-#include "../../parameters.h"
+#include "parameters.h"
 #endif
 
 #if !defined(__MATHS_H)
-#include "../../MOL++/maths.h"
+#include "MOL++/maths.h"
 #endif
 
 using namespace std;
 
-//=========================
-int test_maths (int detail)
-//=========================
+//==========================
+bool test_maths (int detail)
+//==========================
 {
-  int result=1;
+  bool result = true;
 
   long double x= 5.2375, y = -5.2375;
 
@@ -73,6 +73,11 @@ int test_maths (int detail)
   if (detail) affiche ("sgn", sgn(x)==1 && sgn(-x)==-1);
   else result *= (sgn(x)==1 && sgn(-x)==-1);
 
+  if (detail) affiche ("sup", sup(x,y) == x && sup(abs(x),abs(y))==x);
+  else result *= (sup(x,y) == x && sup(abs(x),abs(y))==x);
+
+  if (detail) affiche ("inf", inf(x,y) == y && inf(abs(x),abs(y))==x);
+  else result *= (inf(x,y) == y && inf(abs(x),abs(y))==x);
 
   if (detail) affiche ("pi", abs(pi()-3.14159265358979323846264338327950288419716939937510) < epsilon);
   else result *= (abs(pi()-3.14159265358979323846264338327950288419716939937510)<epsilon);
@@ -84,6 +89,14 @@ int test_maths (int detail)
   if (detail) affiche ("inverse factorial", inv_factorial(reel)==9 && inv_factorial(x)==-1);
   else result *= (inv_factorial(reel)==9 && inv_factorial(x)==-1);
 
+  long double a, b, c, d, e;
+  a = 0; b = 0.5*epsilon;
+  c = 1.E15;
+  d = c * (1+0.5*epsilon);
+  e = c * (1+epsilon);
+  if (detail) affiche ("relative error", relative_error(a,b) && relative_error(c,d) && !relative_error(c,e));
+  else result *= (relative_error(a,b) && relative_error(c,d) && !relative_error(c,e));
+
   cout << endl;
 
   cout << "============================================================== \n";
