@@ -1,13 +1,13 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 1.7.0                   *
+ *                   GNU/linux version 1.7.6                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006 COLLARD Christophe
+ * copyright  2003,2004,2005,2006,2007 COLLARD Christophe
  * copyright  2003,2004 CREUSE Emmanuel
  * copyright  2003,2004 MERCIER Denis
- * copyright  2003,2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*
@@ -50,15 +50,15 @@
 #endif
 
 #if !defined(__VECTORS_H)
-#include "../../MOL++/vectors.h"
+#include "MOL++/vectors.h"
 #endif
 
 #if !defined(__MATRIX_H)
-#include "../../MOL++/matrix.h"
+#include "MOL++/matrix.h"
 #endif
 
 #if !defined(__AFFICHE_h)
-#include "../affiche.h"
+#include "tests/affiche.h"
 #endif
 
 
@@ -82,14 +82,6 @@ int test_matrix (int detail)
 
   matrix<double> a(9,9) , c, d, e(9,9), f(9,9), g(9,9),h(9,9), Id(9,9);
 
-  bool test = true;
-  int size = 0;
-  if (a) size = a;
-  else test = false;
-  if (c) test = false;
-  if (detail) affiche ("cast operator () matrix -> int", test && size==a.Rows());
-  else result *= (test && size==a.Rows());
-
   if (detail) affiche ("operator !", !(!a) && !c);
   else result *= (!(!a) && !c);
 
@@ -157,8 +149,8 @@ int test_matrix (int detail)
   mtrx3 &= mtrx4;
   mtrx5 &= nca;
   mtrx7 &= mtrx8;
-  if (detail) affiche ("operator &= (copy without size check)", mtrx2==mtx && mtrx && !mtrx3 && mtrx7==mtx && nca==mtrx5 && mtrx5.Columns()==nca.Columns());
-  else result *= (mtrx2==mtx && mtrx && !mtrx3 && mtrx7==mtx && nca==mtrx5 && mtrx5.Columns()==nca.Columns());
+  if (detail) affiche ("operator &= (copy without size check)", mtrx2==mtx && mtrx.Rows() && !mtrx3 && mtrx7==mtx && nca==mtrx5 && mtrx5.Columns()==nca.Columns());
+  else result *= (mtrx2==mtx && mtrx.Rows() && !mtrx3 && mtrx7==mtx && nca==mtrx5 && mtrx5.Columns()==nca.Columns());
 
   matrix<double> mtrx9;
   mtrx = mtrx8 = mtx;
@@ -374,6 +366,13 @@ int test_matrix (int detail)
   if (detail) affiche("read/write", ncd==fmat);
   else result *= (ncd==fmat);
 
+  string filename = "matrix.res";
+  ncd.save(filename);
+  matrix<double> fmat2(ncd.Rows(), ncd.Columns());
+  fmat2.read(filename);
+  if (detail) affiche("read/write with a string argument", ncd==fmat2);
+  else result *= (ncd==fmat2);
+
   matrix<double> mtxinvref = mtx;
   matrix<double> mtxinv = mtx;
   vector<double> vectinv;
@@ -501,4 +500,5 @@ int test_matrix (int detail)
 
 }
 
+
 #endif
