@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 1.1.8                   *
+ *                   GNU/linux version 1.2.4                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006 COLLARD Christophe
- * copyright  2003,2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2003,2004,2005,2006,2007 COLLARD Christophe
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*
@@ -48,15 +48,15 @@
 #endif
 
 #if !defined(__VECTORS_H)
-#include "../../MOL++/vectors.h"
+#include "MOL++/vectors.h"
 #endif
 
 #if !defined(__POLYNOMS_H)
-#include "../../MOL++/polynoms.h"
+#include "MOL++/polynoms.h"
 #endif
 
 #if !defined(__AFFICHE_h)
-#include "../affiche.h"
+#include "tests/affiche.h"
 #endif
 
 
@@ -88,11 +88,6 @@ int test_polynom (int detail)
 
   bool test = true;
   int size = 0;
-  if (u) size = u;
-  else test = false;
-  if (x) test = false;
-  if (detail) affiche ("cast operator () polynom -> int", test && size==u.degree()+1);
-  else result *= (test && size==u.degree()+1);
 
   if (detail) affiche ("operator !", !(!u) && !x);
   else result *= (!(!u) && !x);
@@ -242,6 +237,13 @@ int test_polynom (int detail)
   if (detail) affiche("read/write", v==fvect);
   else result *= (v==fvect);
 
+  string filename = "polynome.res";
+  v.save(filename);
+  polynom<long double> fvect2(9);
+  fvect2.read(filename);
+  if (detail) affiche("read/write with a string argument", v==fvect2);
+  else result *= (v==fvect2);
+
   polynom<long double> zpermute = z;
   zpermute.permute(5,7);
   zpermute.permute(9,0);
