@@ -1,12 +1,12 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 1.5.6                   *
+ *	             GNU/linux version 1.6.4                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006 COLLARD Christophe
+ * copyright  2003,2004,2005,2006,2007 COLLARD Christophe
  * copyright  2003,2004 CREUSE Emmanuel
- * copyright  2003,2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*
@@ -49,19 +49,19 @@
 #endif
 
 #if !defined(__VECTORS_H)
-#include "../../MOL++/vectors.h"
+#include "MOL++/vectors.h"
 #endif
 
 #if !defined(__MATRIX_H)
-#include "../../MOL++/matrix.h"
+#include "MOL++/matrix.h"
 #endif
 
 #if !defined(__SYMMATRIX_H)
-#include "../../MOL++/symmatrix.h"
+#include "MOL++/symmatrix.h"
 #endif
 
 #if !defined(__AFFICHE_h)
-#include "../affiche.h"
+#include "tests/affiche.h"
 #endif
 
 
@@ -130,14 +130,6 @@ int test_symmatrix (int detail)
   symmatrix<long double> smat(5), smat2, smat3, smat4(5), smat5(5,5);
   vector<long double> ve(5);
 
-  bool test = true;
-  int size = 0;
-  if (smat) size = smat;
-  else test = false;
-  if (smat2) test = false;
-  if (detail) affiche ("cast operator () symmatrix -> int", test && size==smat.Rows());
-  else result *= (test && size==smat.Rows());
-
   if (detail) affiche ("operator !", !(!smat) && !smat2);
   else result *= (!(!smat) && !smat2);
 
@@ -183,6 +175,9 @@ int test_symmatrix (int detail)
   if (detail) affiche ("constructor", smtc==smtc2 && smtc==smtc3 && smtc==smtc4);
   else result *= smtc==smtc2 && smtc==smtc3 && smtc==smtc4;
 
+  if (detail) affiche ("cast constructor matrix -> symmatrix", (symmatrix<long double>) m == smat);
+  else result *= ((symmatrix<long double>) m == smat);
+
   smat2 = smat;
   if (detail) affiche ("operator = symmat/symmat", smat2==m && smat2[1].dim()==1);
   else result *= (smat2==m && smat2[1].dim()==1);
@@ -214,8 +209,8 @@ int test_symmatrix (int detail)
   mtrx2 &= mtrx;
   mtrx3 &= mtrx4;
   mtrx7 &= mtrx8;
-  if (detail) affiche ("operator &= (copy without size check)", mtrx2==meq1 && mtrx && !mtrx3 && mtrx7==meq1);
-  else result *= (mtrx2==meq1 && mtrx && !mtrx3 && mtrx7==meq1);
+  if (detail) affiche ("operator &= (copy without size check)", mtrx2==meq1 && mtrx.Rows() && !mtrx3 && mtrx7==meq1);
+  else result *= (mtrx2==meq1 && mtrx.Rows() && !mtrx3 && mtrx7==meq1);
 
   symmatrix<double> mtrx9;
   mtrx = mtrx8 = meq1;
@@ -397,7 +392,14 @@ int test_symmatrix (int detail)
   fsymat.read("symmat.res");
   if (detail) affiche ("read/write", fsymat==smat && fsymat[1].dim()==1);
   else result *= (fsymat==smat && fsymat[1].dim()==1);
-  
+
+  string filename = "symmatrix.res";
+  smat.save(filename);
+  symmatrix<long double> fsymat2(smat.Rows());
+  fsymat2.read(filename);
+  if (detail) affiche("read/write with a string argument", smat==fsymat2);
+  else result *= (smat==fsymat2);
+
   if (detail) affiche ("gauss", mata*gauss(mata)==Id && gauss(mata)[1].dim()==1);
   else result *= (mata*gauss(mata)==Id && gauss(mata)[1].dim()==1);
 
