@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 0.3.8                   *
+ *	             GNU/linux version 0.4.4                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2004,2005,2006 COLLARD Christophe
- * copyright  2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2004,2005,2006,2007 COLLARD Christophe
+ * copyright  2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*
@@ -48,15 +48,15 @@
 #endif
 
 #if !defined(__VECTORS_H)
-#include "../../MOL++/vectors.h"
+#include "MOL++/vectors.h"
 #endif
 
 #if !defined(__TENSORS2_H)
-#include "../../MOL++/tensors2.h"
+#include "MOL++/tensors2.h"
 #endif
 
 #if !defined(__AFFICHE_h)
-#include "../affiche.h"
+#include "tests/affiche.h"
 #endif
 
 
@@ -80,14 +80,6 @@ int test_tensor2 (int detail)
 
   tensor2<double> a(9,9) , c, d, e(9,9), f(9,9), g(9,9),h(9,9), Id(9,9);
 
-  bool test = true;
-  int size = 0;
-  if (a) size = a;
-  else test = false;
-  if (c) test = false;
-  if (detail) affiche ("cast operator () tensor2 -> int", test && size==a.dim1());
-  else result *= (test && size==a.dim1());
-
   if (detail) affiche ("operator !", !(!a) && !c);
   else result *= (!(!a) && !c);
 
@@ -153,8 +145,8 @@ int test_tensor2 (int detail)
   mtrx3 &= mtrx4;
   mtrx5 &= nca;
   mtrx7 &= mtrx8;
-  if (detail) affiche ("operator &= (copy without size check)", mtrx2==mtx && mtrx && !mtrx3 && mtrx7==mtx && nca==mtrx5 && mtrx5.dim2()==nca.dim2());
-  else result *= (mtrx2==mtx && mtrx && !mtrx3 && mtrx7==mtx && nca==mtrx5 && mtrx5.dim2()==nca.dim2());
+  if (detail) affiche ("operator &= (copy without size check)", mtrx2==mtx && mtrx.dim1() && !mtrx3 && mtrx7==mtx && nca==mtrx5 && mtrx5.dim2()==nca.dim2());
+  else result *= (mtrx2==mtx && mtrx.dim1() && !mtrx3 && mtrx7==mtx && nca==mtrx5 && mtrx5.dim2()==nca.dim2());
 
   tensor2<double> mtrx9;
   mtrx = mtrx8 = mtx;
@@ -358,6 +350,13 @@ int test_tensor2 (int detail)
   if (detail) affiche("read/write", ncd==fmat);
   else result *= (ncd==fmat);
 
+  string filename = "tenseur2.res";
+  ncd.save(filename);
+  tensor2<double> fmat2(ncd.Rows(), ncd.Columns());
+  fmat2.read(filename);
+  if (detail) affiche("read/write with a string argument", ncd==fmat2);
+  else result *= (ncd==fmat2);
+
   tensor2<double> mtxinvref = mtx;
   tensor2<double> mtxinv = mtx;
   vector<double> vectinv;
