@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 1.3.4                   *
+ *                   GNU/linux version 1.4.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006 COLLARD Christophe
- * copyright  2003,2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2003,2004,2005,2006,2007 COLLARD Christophe
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*
@@ -48,27 +48,27 @@
 #endif
 
 #if !defined(__VECTORS_H)
-#include "../../MOL++/vectors.h"
+#include "MOL++/vectors.h"
 #endif
 
 #if !defined(__MATRIX_H)
-#include "../../MOL++/matrix.h"
+#include "MOL++/matrix.h"
 #endif
 
 #if !defined(__SYMMATRIX_H)
-#include "../../MOL++/symmatrix.h"
+#include "MOL++/symmatrix.h"
 #endif
 
 #if !defined(__TENSORS2_H)
-#include "../../MOL++/tensors2.h"
+#include "MOL++/tensors2.h"
 #endif
 
 #if !defined(__TENSORS3_H)
-#include "../../MOL++/tensors3.h"
+#include "MOL++/tensors3.h"
 #endif
 
 #if !defined(__AFFICHE_h)
-#include "../affiche.h"
+#include "tests/affiche.h"
 #endif
 
 
@@ -82,11 +82,6 @@ int test_tensor3 (int detail)
 
   bool test = true;
   int size = 0;
-  if (t1) size = t1;
-  else test = false;
-  if (t3) test = false;
-  if (detail) affiche ("cast operator () tensor3 -> int", test && size==t1.dim1());
-  else result *= (test && size==t1.dim1());
 
   if (detail) affiche ("operator !", !(!t1) && !t3);
   else result *= (!(!t1) && !t3);
@@ -175,8 +170,8 @@ int test_tensor3 (int detail)
   mtrx5 &= ntsr1;
   mtrx6 &= ntsr1;
   mtrx7 &= mtrx8;
-  if (detail) affiche ("operator &= (copy without size check)", mtrx2==ntsr1 && mtrx && !mtrx3 && mtrx7==ntsr1 && mtrx5==ntsr1 && mtrx6==ntsr1);
-  else result *= (mtrx2==ntsr1 && mtrx && !mtrx3 && mtrx7==ntsr1 && mtrx5==ntsr1 && mtrx6==ntsr1);
+  if (detail) affiche ("operator &= (copy without size check)", mtrx2==ntsr1 && mtrx.dim1() && !mtrx3 && mtrx7==ntsr1 && mtrx5==ntsr1 && mtrx6==ntsr1);
+  else result *= (mtrx2==ntsr1 && mtrx.dim1() && !mtrx3 && mtrx7==ntsr1 && mtrx5==ntsr1 && mtrx6==ntsr1);
 
   tensor3<long double> mtrx9, mtrx10;
   mtrx = mtrx8 = ntsr1;
@@ -312,6 +307,13 @@ int test_tensor3 (int detail)
   if (detail) affiche("read/write", ncd==ts3);
   else result *= (ncd==ts3);
 
+  string filename = "tenseur3.res";
+  ts3.save(filename);
+  tensor3<long double> ncd2(ts3.dim1(), ts3.dim2(), ts3.dim3());
+  ncd2.read(filename);
+  if (detail) affiche("read/write with a string argument", ncd2==ts3);
+  else result *= (ncd2==ts3);
+
   cout << endl;  
 
   cout << "============================================================== \n";
