@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 1.3.8                   *
+ *	             GNU/linux version 1.4.6                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006 COLLARD Christophe
- * copyright  2003,2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2003,2004,2005,2006,2007 COLLARD Christophe
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*
@@ -48,31 +48,31 @@
 #endif
 
 #if !defined(__VECTORS_H)
-#include "../../MOL++/vectors.h"
+#include "MOL++/vectors.h"
 #endif
 
 #if !defined(__MATRIX_H)
-#include "../../MOL++/matrix.h"
+#include "MOL++/matrix.h"
 #endif
 
 #if !defined(__SYMMATRIX_H)
-#include "../../MOL++/symmatrix.h"
+#include "MOL++/symmatrix.h"
 #endif
 
 #if !defined(__TENSORS2_H)
-#include "../../MOL++/tensors2.h"
+#include "MOL++/tensors2.h"
 #endif
 
 #if !defined(__TENSORS3_H)
-#include "../../MOL++/tensors3.h"
+#include "MOL++/tensors3.h"
 #endif
 
 #if !defined(__TENSORS4_H)
-#include "../../MOL++/tensors4.h"
+#include "MOL++/tensors4.h"
 #endif
 
 #if !defined(__AFFICHE_h)
-#include "../affiche.h"
+#include "tests/affiche.h"
 #endif
 
 
@@ -86,11 +86,6 @@ int test_tensor4 (int detail)
 
   bool test = true;
   int size = 0;
-  if (t1) size = t1;
-  else test = false;
-  if (t3) test = false;
-  if (detail) affiche ("cast operator () tensor4 -> int", test && size==t1.dim1());
-  else result *= (test && size==t1.dim1());
 
   if (detail) affiche ("operator !", !(!t1) && !t3);
   else result *= (!(!t1) && !t3);
@@ -177,8 +172,8 @@ int test_tensor4 (int detail)
   mtrx6 &= ntsr1;
   mtrx0 &= ntsr1;
   mtrx7 &= mtrx8;
-  if (detail) affiche ("operator &= (copy without size check)", mtrx2==ntsr1 && mtrx && !mtrx3 && mtrx7==ntsr1 && mtrx5==ntsr1 && mtrx6==ntsr1 && mtrx0==ntsr1);
-  else result *= (mtrx2==ntsr1 && mtrx && !mtrx3 && mtrx7==ntsr1 && mtrx5==ntsr1 && mtrx6==ntsr1 && mtrx0==ntsr1);
+  if (detail) affiche ("operator &= (copy without size check)", mtrx2==ntsr1 && mtrx.dim1() && !mtrx3 && mtrx7==ntsr1 && mtrx5==ntsr1 && mtrx6==ntsr1 && mtrx0==ntsr1);
+  else result *= (mtrx2==ntsr1 && mtrx.dim1() && !mtrx3 && mtrx7==ntsr1 && mtrx5==ntsr1 && mtrx6==ntsr1 && mtrx0==ntsr1);
 
   tensor4<long double> mtrx9, mtrx10;
   mtrx = mtrx8 = ntsr1;
@@ -392,12 +387,55 @@ int test_tensor4 (int detail)
   if (detail) affiche("Id4s", Id_4==Id4s<long double>(3) && (Id4s<long double>(nsz) || Tsr4s)==Tsr4s && (Tsr4s || Id4s<long double>(nsz))==Tsr4s);
   else result *= (Id_4==Id4s<long double>(3) && (Id4s<long double>(nsz) || Tsr4s)==Tsr4s && (Tsr4s || Id4s<long double>(nsz))==Tsr4s);
 
+  matrix<long double> P(3,3);
+  matrix<long double> passlg(3,3); // orthogonal matrix
+  tensor4<long double> tsr(3), tsr2(3), C(3);
+  for (int i=1; i<=3; i++)
+    for (int j=1; j<=3; j++)
+      P(i,j) = (2.52*i - 1.25*j + 25 * (i==j)) * 1E-2;
+  long double phi1=173.464, phi=104.504, phi2=34.5;
+  passlg(1,1) =  cos(phi1) * cos(phi2)  -  sin(phi1) * cos(phi) * sin(phi2);
+  passlg(1,2) = -cos(phi1) * sin(phi2)  -  sin(phi1) * cos(phi) * cos(phi2);
+  passlg(1,3) =  sin(phi1) * sin(phi);
+  passlg(2,1) =  sin(phi1) * cos(phi2)  +  cos(phi1) * cos(phi) * sin(phi2);
+  passlg(2,2) = -sin(phi1) * sin(phi2)  +  cos(phi1) * cos(phi) * cos(phi2);
+  passlg(2,3) = -cos(phi1) * sin(phi);
+  passlg(3,1) =  sin(phi)  * sin(phi2);
+  passlg(3,2) =  sin(phi)  * cos(phi2);
+  passlg(3,3) =  cos(phi);
+  for (int i=1; i<=3; i++)
+    for (int j=1; j<=3; j++)
+      for (int k=1; k<=3; k++)
+	for (int l=1; l<=3; l++)
+	  { C(i,j,k,l) = (2.4*i -j / (1.2*i) ) * k - 3.1*l;
+	    for (int p=1; p<=3; p++)
+	      for (int q=1; q<=3; q++)
+		for (int m=1; m<=3; m++)
+		  for (int n=1; n<=3; n++)
+		    { tsr(p,q,m,n) += P(p,i) * P(q,j) * P(m,k) * P(n,l) * C(i,j,k,l);
+		      tsr2(p,q,m,n) += passlg(p,i) * passlg(q,j) * passlg(m,k) * passlg(n,l) * C(i,j,k,l);
+		    }
+	  }
+  long double scalar = .1;
+  test = true;
+  test *= (tsr2 == change_basis(passlg,C));
+  test *= (tsr == change_basis(P,C));
+  if (detail) affiche ("change basis", test);
+  else result *= test;
+
   t6.save("tensor4.res");
   tensor4<long double> ncd(t6.dim1(), t6.dim2(), t6.dim3(), t6.dim4());
   ncd.read("tensor4.res");
   if (detail) affiche("read/write", ncd==t6);
   else result *= (ncd==t6);
 
+  string filename = "tenseur4.res";
+  t6.save(filename);
+  tensor4<long double> ncd2(t6.dim1(), t6.dim2(), t6.dim3(), t6.dim4());
+  ncd2.read(filename);
+  if (detail) affiche("read/write with a string argument", ncd2==t6);
+  else result *= (ncd2==t6);
+
   cout << endl;  
 
   cout << "============================================================== \n";
