@@ -1,13 +1,13 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 1.4.4                   *
+ *                   GNU/linux version 1.5.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006 COLLARD Christophe
+ * copyright  2003,2004,2005,2006,2007 COLLARD Christophe
  * copyright  2003,2004 CREUSE Emmanuel
  * copyright  2003,2004 MERCIER Denis
- * copyright  2003,2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*
@@ -50,11 +50,11 @@
 #endif
 
 #if !defined(__VECTORS_H)
-#include "../../MOL++/vectors.h"
+#include "MOL++/vectors.h"
 #endif
 
 #if !defined(__AFFICHE_H)
-#include "../affiche.h"
+#include "tests/affiche.h"
 #endif
 
 
@@ -83,14 +83,6 @@ int test_vector (int detail)
   if (detail) affiche ("dim()", u.dim()==9);
   else result *= (u.dim()==9);
 
-  bool test = true;
-  int size = 0;
-  if (u) size = u;
-  else test = false;
-  if (x) test = false;
-  if (detail) affiche ("cast operator () vector -> int", test && size==u.dim());
-  else result *= (test && size==u.dim());
-
   if (detail) affiche ("operator !", !(!u) && !x);
   else result *= (!(!u) && !x);
 
@@ -225,6 +217,13 @@ int test_vector (int detail)
   if (detail) affiche("read/write", v==fvect);
   else result *= (v==fvect);
 
+  string filename="vector.res";
+  v.save(filename);
+  vector<long double> fvect2(v.dim());
+  fvect2.read(filename);
+  if (detail) affiche("read/write with a string argument", v==fvect2);
+  else result *= (v==fvect2);
+
   if (detail) affiche ("norm", (v.norm()-398.361958525158)<1e-12);
   else result *= (v.norm()-398.361958525158)<1e-12;
 
